@@ -5,3 +5,5 @@ from quickstats.components.extended_model import ExtendedModel
 from quickstats.components.nuisance_parameter_pull import NuisanceParameterPull
 from quickstats.components.roofit_plotter import RooFitPlotter
 from quickstats.components.nuisance_parameter_harmonizer import NuisanceParameterHarmonizer
+from quickstats.components.analysis_object import AnalysisObject
+from quickstats.components.asymptotic_cls import AsymptoticsCLs
\ No newline at end of file
